﻿using System.Collections.Generic;
using DevExpress.ExpressApp.DC;
using DevExpress.Persistent.Base;
using Xafari;
using Xafari.BC.DC;
using Xafari.DC;
using Xafari.XF;

namespace Ticket33663_XF_ManyToMany.Module.BusinessObjects
{
	[DomainComponent]
	[RegisterEntity]
	[NavigationItem]
	public interface Airport : IXFEntity
	{
		string NameAirport { get; set; }
	}

[DomainComponent]
[NonPersistentDc]
[EntityExtension(typeof(Airport))]
[RegisterExtension(typeof(Airport))]
	public interface AirportExtension : IXFEntityExtension
	{
		string Describe { get; }

		[BackReferenceProperty("__FlightExtension.Stopovers")]
		[NonPersistentDc]
		[XPWeakManyToMany()]
		IList<Flight> Flights { get; }
	}

	[DomainLogic(typeof(AirportExtension))]
	public class AirportExtensionLogic : DomainLogicBase<AirportExtension>
	{
		public AirportExtensionLogic(AirportExtension instance)
			: base(instance)
		{
		}

		public string Get_Describe()
		{
			return "This is Airport Extension" + this.Instance.Airport().NameAirport;
		}

		public IList<Flight> Flights
		{
			get { return this.GetWeakList(x => x.Flights); }
		}
	}

	public static class AirportExtension_Extension
	{
		public static AirportExtension AirportExtension(this Airport entity)
		{
			return entity.GetExtension<AirportExtension>();
		}

		public static Airport Airport(this AirportExtension extension)
		{
			return extension.GetEntity<Airport>();
		}
	}
}