﻿using System.Collections.Generic;
using DevExpress.ExpressApp.DC;
using DevExpress.Persistent.Base;
using Xafari;
using Xafari.BC.DC;
using Xafari.DC;
using Xafari.XF;

namespace Ticket33663_XF_ManyToMany.Module.BusinessObjects
{
	[DomainComponent]
	[RegisterEntity]
	[NavigationItem]
	public interface Flight : IXFEntity
	{
		string NameFlight { get; set; }
	}

	[DomainComponent]
	[NonPersistentDc]
	[EntityExtension(typeof(Flight))]
	[RegisterExtension(typeof(Flight))]
	public interface FlightExtension : IXFEntityExtension
	{
		string Describe { get; }

		[BackReferenceProperty("__AirportExtension.Flights")]
		[NonPersistentDc]
		[XPWeakManyToMany()]
		IList<Airport> Stopovers { get; }
	}

	[DomainLogic(typeof(FlightExtension))]
	public class FlightExtensionLogic : DomainLogicBase<FlightExtension>
	{
		public FlightExtensionLogic(FlightExtension instance)
			: base(instance)
		{
		}

		public string Get_Describe()
		{
			return "This is Flight Extension "+ this.Instance.Flight().NameFlight;
		}

		public IList<Airport> Stopovers
		{
			get { return this.GetWeakList(x => x.Stopovers); }
		}

	}

	public static class FlightExtension_Extension
	{
		public static FlightExtension FlightExtension(this Flight entity)
		{
			return entity.GetExtension<FlightExtension>();
		}

		public static Flight Flight(this FlightExtension extension)
		{
			return extension.GetEntity<Flight>();
		}
	}
}